@@ -2,24 +2,21 @@
 
 from __future__ import print_function, absolute_import, division, unicode_literals
 
-# install_requires of ruamel.base is not really required but the old
-# ruamel.base installed __init__.py, and thus a new version should
-# be installed at some point
-
 if False:  # MYPY
     from typing import Dict, Any  # NOQA
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 15, 4),
-    __version__='0.15.4',
+    version_info=(0, 15, 12),
+    __version__='0.15.12',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
     entry_points=None,
+    since=2014,
     extras_require={':platform_python_implementation=="CPython" and python_version<="2.7"': [
         'ruamel.ordereddict',
-        ]},
+        ], 'jinja2': ['ruamel.yaml.jinja2>=0.2']},
     ext_modules=[dict(
             name='_ruamel_yaml',
             src=['ext/_ruamel_yaml.c', 'ext/api.c', 'ext/writer.c', 'ext/dumper.c',
@@ -49,8 +46,14 @@ _package_data = dict(
     read_the_docs='yaml',
     many_linux='libyaml-devel',
     supported=[(2, 7), (3, 3)],  # minimum
+    tox=dict(
+        env='*p',
+        deps='ruamel.std.pathlib',
+        fl8excl='_test/lib',
+    ),
 )  # type: Dict[Any, Any]
 
+
 version_info = _package_data['version_info']
 __version__ = _package_data['__version__']
 
